@@ -1,5 +1,5 @@
 /*
- * $Id: ConnectionSettings.cpp 109 2011-09-18 08:50:58Z werner $
+ * $Id: ConnectionSettings.cpp 120 2012-03-08 04:57:41Z werner $
  *
  * File:   ConnectionSettings.cpp
  * Author: Werner Jaeger
@@ -53,6 +53,7 @@ static const QString IP = "Ppp/Ip";
 /** properties */
 static const QString NAME = "name";
 static const QString AUTOCONNECT = "auoConnect";
+static const QString DISABLEIPSECENCRYPTION = "disableIPSecEncryption";
 static const QString GATEWAY = "gateway";
 static const QString IDENTITY = "identity";
 static const QString USERNAME = "userName";
@@ -111,7 +112,7 @@ ConnectionSettings::~ConnectionSettings()
 
 int ConnectionSettings::connections() const
 {
-   const int iSize = qSettings()->beginReadArray(CONNECTIONS);
+   const int iSize(qSettings()->beginReadArray(CONNECTIONS));
    qSettings()->endArray();
 
    return(iSize);
@@ -123,7 +124,7 @@ ConnectionSettings::Result ConnectionSettings::addConnection(const QString& strN
 
    if (result == Ok)
    {
-      const int iSize = connections();
+      const int iSize(connections());
 
       qSettings()->beginWriteArray(CONNECTIONS);
       qSettings()->setArrayIndex(iSize);
@@ -136,7 +137,7 @@ ConnectionSettings::Result ConnectionSettings::addConnection(const QString& strN
 
 bool ConnectionSettings::removeConnection(int iConnectionNo) const
 {
-   bool fRet = iConnectionNo < connections() && qSettings()->isWritable();
+   bool fRet(iConnectionNo < connections() && qSettings()->isWritable());
 
    if (fRet)
    {
@@ -179,11 +180,41 @@ PppSettings ConnectionSettings::pppSettings(const QString& strName) const
    return(PppSettings(connection(strName)));
 }
 
+int ConnectionSettings::deleteAllConfFiles()
+{
+   int iRet(0);
+
+   if (ConnectionsModel().isWriteable())
+   {
+      for (int i = 0; i < ConfWriter::END; i++)
+      {
+         const QString strConfFile(ConfWriter::fileName(static_cast<ConfWriter::Conf>(i)));
+         if (QFile::exists(strConfFile))
+            QFile::remove(strConfFile);
+      }
+
+      const int iConnections(connections());
+
+      for (int i = 0; i < iConnections; i++)
+      {
+         const QString strConnectionName(connection(i));
+         QFile::remove(ConfWriter::fileName(ConfWriter::PPP, strConnectionName));
+
+         const QString strDNSConfInstance(QCoreApplication::instance()->objectName() + "-" +strConnectionName);
+         QFile::remove(ConfWriter::fileName(ConfWriter::PPPDNSCONF, strDNSConfInstance));
+      }
+   }
+   else
+      iRet = -1;
+
+   return(iRet);
+}
+
 QString ConnectionSettings::connection(int iConnectionNo) const
 {
    QString strRet;
 
-   const int iSize = qSettings()->beginReadArray(CONNECTIONS);
+   const int iSize(qSettings()->beginReadArray(CONNECTIONS));
    if (iConnectionNo < iSize)
    {
       qSettings()->setArrayIndex(iConnectionNo);
@@ -197,8 +228,8 @@ QString ConnectionSettings::connection(int iConnectionNo) const
 int ConnectionSettings::connection(const QString& strName) const
 {
    int iRet;
-   bool fFound = false;
-   const int iSize = qSettings()->beginReadArray(CONNECTIONS);
+   bool fFound(false);
+   const int iSize(qSettings()->beginReadArray(CONNECTIONS));
    for (iRet = 0; !fFound && iRet < iSize; iRet++)
    {
       qSettings()->setArrayIndex(iRet);
@@ -226,7 +257,7 @@ ConnectionSettings::Result ConnectionSettings::validateName(const QString& strNa
 /*********** helpers ***************/
 bool ConnectionSettings::setValue(const QString& strValue, const QString& strPath) const
 {
-   const bool fRet = m_iConnectionNo >= 0 && qSettings()->isWritable();
+   const bool fRet(m_iConnectionNo >= 0 && qSettings()->isWritable());
 
    if (fRet)
    {
@@ -257,7 +288,7 @@ QString ConnectionSettings::getStringValue(const QString& strPath) const
 
 bool ConnectionSettings::setSecret(const QString& strValue, const QString& strPath) const
 {
-   const bool fRet = m_iConnectionNo >= 0 && qSettings()->isWritable();
+   const bool fRet(m_iConnectionNo >= 0 && qSettings()->isWritable());
 
    if (fRet)
    {
@@ -291,7 +322,7 @@ QString ConnectionSettings::getSecret(const QString& strPath) const
 
 bool ConnectionSettings::setValue(int iValue, const QString& strPath) const
 {
-   const bool fRet = m_iConnectionNo >= 0 && qSettings()->isWritable();
+   const bool fRet(m_iConnectionNo >= 0 && qSettings()->isWritable());
 
    if (fRet)
    {
@@ -307,7 +338,7 @@ bool ConnectionSettings::setValue(int iValue, const QString& strPath) const
 
 int ConnectionSettings::getIntValue(const QString& strPath, int iDefault) const
 {
-   int iRet = 0;
+   int iRet(0);
 
    if (m_iConnectionNo >= 0)
    {
@@ -322,7 +353,7 @@ int ConnectionSettings::getIntValue(const QString& strPath, int iDefault) const
 
 bool ConnectionSettings::setValue(bool fValue, const QString& strPath) const
 {
-   const bool fRet = m_iConnectionNo >= 0 && qSettings()->isWritable();
+   const bool fRet(m_iConnectionNo >= 0 && qSettings()->isWritable());
 
    if (fRet)
    {
@@ -338,7 +369,7 @@ bool ConnectionSettings::setValue(bool fValue, const QString& strPath) const
 
 bool ConnectionSettings::getBoolValue(const QString& strPath, bool fDefault) const
 {
-   bool fRet = false;
+   bool fRet(false);
 
    if (m_iConnectionNo >= 0)
    {
@@ -353,7 +384,7 @@ bool ConnectionSettings::getBoolValue(const QString& strPath, bool fDefault) con
 
 bool ConnectionSettings::setRouteProperty(const QString& strValue, int iRow, const QString strPropertyName) const
 {
-   bool fRet = m_iConnectionNo >= 0 && qSettings()->isWritable();
+   bool fRet(m_iConnectionNo >= 0 && qSettings()->isWritable());
 
    if (fRet)
    {
@@ -361,7 +392,7 @@ bool ConnectionSettings::setRouteProperty(const QString& strValue, int iRow, con
       qSettings()->setArrayIndex(m_iConnectionNo);
       qSettings()->beginGroup(IP);
 
-      const int iSize = qSettings()->beginReadArray(ROUTES);
+      const int iSize(qSettings()->beginReadArray(ROUTES));
       if (iRow < iSize)
       {
          qSettings()->setArrayIndex(iRow);
@@ -390,7 +421,7 @@ QString ConnectionSettings::routeProperty(int iRow, const QString strPropertyNam
       qSettings()->setArrayIndex(m_iConnectionNo);
       qSettings()->beginGroup(IP);
 
-      const int iSize = qSettings()->beginReadArray(ROUTES);
+      const int iSize(qSettings()->beginReadArray(ROUTES));
       if (iRow < iSize)
       {
          qSettings()->setArrayIndex(iRow);
@@ -417,6 +448,17 @@ bool CommonSettings::autoConnect() const
    return(getBoolValue(COMMON + '/' + AUTOCONNECT));
 }
 
+bool CommonSettings::setDisableIPSecEncryption(bool fDisableIPSecEncryption) const
+{
+   return(setValue(fDisableIPSecEncryption, COMMON + '/' + DISABLEIPSECENCRYPTION));
+}
+
+bool CommonSettings::disableIPSecEncryption() const
+{
+   return(getBoolValue(COMMON + '/' + DISABLEIPSECENCRYPTION));
+}
+
+
 /********** IPsec ************/
 
 bool IPSecSettings::setGateway(const QString& strGateway) const
@@ -763,7 +805,7 @@ bool PppIpSettings::useDefaultGateway() const
 
 int PppIpSettings::routes() const
 {
-   int iSize = 0;
+   int iSize(0);
 
    if (connectionNo() >= 0)
    {
@@ -811,15 +853,16 @@ QString PppIpSettings::routeComment(int iRow) const
 
 bool PppIpSettings::addRoute() const
 {
-   bool fAdded = false;
+   bool fAdded(false);
 
    if (connectionNo() >= 0)
    {
+      const int iSize(routes());
+
       qSettings()->beginReadArray(CONNECTIONS);
       qSettings()->setArrayIndex(connectionNo());
       qSettings()->beginGroup(IP);
 
-      const int iSize = routes();
       qSettings()->beginWriteArray(ROUTES);
       qSettings()->setArrayIndex(iSize);
       qSettings()->setValue(IPADDRESS, "");
@@ -836,7 +879,7 @@ bool PppIpSettings::addRoute() const
 
 bool PppIpSettings::removeRoute(int iRow) const
 {
-   bool fRemoved = false;
+   bool fRemoved(false);
 
    if (connectionNo() >= 0)
    {
